package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.IOException;
import java.util.Objects;
import org.apache.bcel.generic.Type;
import org.apache.bcel.util.BCELComparator;

/* loaded from: org_apache_bcel_classfile.jar:org/apache/bcel/classfile/Field.class */
public final class Field extends FieldOrMethod {
    public static final Field[] EMPTY_ARRAY = new Field[0];
    private static BCELComparator bcelComparator = new BCELComparator() { // from class: org.apache.bcel.classfile.Field.1
        public boolean equals(Object o1, Object o2) {
            Field THIS = (Field) o1;
            Field THAT = (Field) o2;
            return Objects.equals(THIS.getName(), THAT.getName()) && Objects.equals(THIS.getSignature(), THAT.getSignature());
        }

        public int hashCode(Object o) {
            Field THIS = (Field) o;
            return THIS.getSignature().hashCode() ^ THIS.getName().hashCode();
        }
    };
    static final Field[] EMPTY_FIELD_ARRAY = new Field[0];

    public static BCELComparator getComparator() {
        return bcelComparator;
    }

    public static void setComparator(BCELComparator comparator) {
        bcelComparator = comparator;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public Field(DataInput file, ConstantPool constantPool) throws IOException, ClassFormatException {
        super(file, constantPool);
    }

    public Field(Field c) {
        super(c);
    }

    public Field(int accessFlags, int nameIndex, int signatureIndex, Attribute[] attributes, ConstantPool constantPool) {
        super(accessFlags, nameIndex, signatureIndex, attributes, constantPool);
    }

    @Override // org.apache.bcel.classfile.Node
    public void accept(Visitor v) {
        v.visitField(this);
    }

    public Field copy(ConstantPool constantPool) {
        return (Field) copy_(constantPool);
    }

    public boolean equals(Object obj) {
        return bcelComparator.equals(this, obj);
    }

    public ConstantValue getConstantValue() {
        for (Attribute attribute : super.getAttributes()) {
            if (attribute.getTag() == 1) {
                return (ConstantValue) attribute;
            }
        }
        return null;
    }

    public Type getType() {
        return Type.getReturnType(getSignature());
    }

    public int hashCode() {
        return bcelComparator.hashCode(this);
    }

    public String toString() {
        String access = Utility.accessToString(super.getAccessFlags());
        String access2 = access.isEmpty() ? "" : access + " ";
        String signature = Utility.signatureToString(getSignature());
        String name = getName();
        StringBuilder buf = new StringBuilder(64);
        buf.append(access2).append(signature).append(" ").append(name);
        ConstantValue cv = getConstantValue();
        if (cv != null) {
            buf.append(" = ").append(cv);
        }
        for (Attribute attribute : super.getAttributes()) {
            if (!(attribute instanceof ConstantValue)) {
                buf.append(" [").append(attribute).append("]");
            }
        }
        return buf.toString();
    }
}
